# cfn-man

Look up cloud formation docs from command line.

## Installation

```
pip install cfn-man
```

## Examples

Type in words to indicate which documents you are looking for

```
cfn-man security group
```

You won't need to type too carefully (powered by Google search)

```
# All three commands below will show the same document
cfn-man auto scaling group
cfn-man asg
cfn-man auato scaligng groudp
```
